@@ -1,6 +1,6 @@
 from captur_ml_sdk.dtypes.generics import Image, Meta
 from pydantic import BaseModel
-from typing import List, Optional
+from typing import List, Optional, Dict
 
 class EvalEventData(BaseModel):
     request_id: str
@@ -9,3 +9,4 @@ class EvalEventData(BaseModel):
     model_name: str
     model_id: str
     model_type: str
+    mapping: Optional[Dict[str, str]]
