@@ -15,9 +15,9 @@ class PreRunEventData(BaseModel):
     images: Optional[List[Image]]
     imagesfile: Optional[str]
     model_name: str
-    base_model_id: str
+    base_model_id: Optional[str]
     include_data: Optional[str]
     exclude_classes: Optional[List[str]]
-    base_dataset_id: str
+    base_dataset_id: Optional[str]
 
     root_validator(check_images_or_imagefile_has_data)
