@@ -5,7 +5,7 @@ from typing import Optional
 class RunEventData(BaseModel):
     gcs_source: str
     model_name: str
-    base_model_id: str
+    base_model_id: Optional[str]
     training_display_name: str
     request_id: str
     request_type: str
